==> py_viptela-0.2-py3-none-any.whl: py_viptela/api/realtime/ospf.py <==
from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

def getDbList(vmanage, deviceId):
    """
    Get OSPF database list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/database?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getDbExt(vmanage, deviceId):
    """
    Get OSPF external database list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/databaseexternal?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getDbSummary(vmanage, deviceId):
    """
    Get OSPF database summary list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/databasesummary?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getInterfaces(vmanage, deviceId):
    """
    Get OSPF interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/interface?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getNeighbors(vmanage, deviceId):
    """
    Get OSPF neighbor list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/neighbor?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getProcess(vmanage, deviceId):
    """
    Get OSPF process list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/process?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getRoutes(vmanage, deviceId):
    """
    Get OSPF route list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/routes?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getV3Interface(vmanage, deviceId):
    """
    Get OSPF v3 interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/v3interface?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response
def getV3Neighbors(vmanage, deviceId):
    """
    Get OSPF v3 neighbor list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ospf/v3neighbor?deviceId={deviceId}"
    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
    return response

==> py_viptela-0.2.3-py3-none-any.whl: py_viptela/api/realtime/ospf.py <==
def getDbList(vmanage, deviceId):
    """
    Get OSPF database list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/database?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDbExt(vmanage, deviceId):
    """
    Get OSPF external database list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/databaseexternal?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDbSummary(vmanage, deviceId):
    """
    Get OSPF database summary list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/databasesummary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaces(vmanage, deviceId):
    """
    Get OSPF interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNeighbors(vmanage, deviceId):
    """
    Get OSPF neighbor list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/neighbor?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getProcess(vmanage, deviceId):
    """
    Get OSPF process list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/process?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRoutes(vmanage, deviceId):
    """
    Get OSPF route list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/routes?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getV3Interface(vmanage, deviceId):
    """
    Get OSPF v3 interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/v3interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getV3Neighbors(vmanage, deviceId):
    """
    Get OSPF v3 neighbor list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/v3neighbor?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
